@@ -22,6 +22,10 @@ if [ -n "$PUPPET_TAGS" ]; then
     TAGS="--tags \"$PUPPET_TAGS\""
 fi
 
+if [ ! -z ${STEP_CONFIG+x} ]; then
+    echo -e "${STEP_CONFIG}" | tee /etc/config.pp
+fi
+
 CHECK_MODE=""
 if [ -d "/tmp/puppet-check-mode" ]; then
     mkdir -p /etc/puppet/check-mode
@@ -68,7 +72,7 @@ verbosity=""
 
 # Disables archiving
 if [ -z "$NO_ARCHIVE" ]; then
-    archivedirs=("/etc" "/root" "/opt" "/var/lib/ironic/tftpboot" "/var/lib/ironic/httpboot" "/var/www" "/var/spool/cron" "/var/lib/nova/.ssh")
+    archivedirs=("/etc" "/root" "/opt" "/var/www" "/var/spool/cron" "/var/lib/nova/.ssh")
     rsync_srcs=""
     for d in "${archivedirs[@]}"; do
         if [ -d "$d" ]; then
@@ -94,7 +98,10 @@ if [ -z "$NO_ARCHIVE" ]; then
 
     # Exclude read-only mounted directories/files which we do not want
     # to copy or delete.
-    ro_files="/etc/puppetlabs/ /opt/puppetlabs/"
+    ro_files="/etc/puppet/ /etc/puppetlabs/ /opt/puppetlabs/ /etc/pki/ca-trust/extracted "
+    ro_files+="/etc/pki/ca-trust/source/anchors /etc/pki/tls/certs/ca-bundle.crt "
+    ro_files+="/etc/pki/tls/certs/ca-bundle.trust.crt /etc/pki/tls/cert.pem "
+    ro_files+="/etc/hosts /etc/localtime /etc/hostname"
     for ro in $ro_files; do
         if [ -e "$ro" ]; then
             exclude_files+=" --exclude=$ro"
@@ -111,7 +118,6 @@ if [ -z "$NO_ARCHIVE" ]; then
     echo "Rsyncing config files from ${rsync_srcs} into ${conf_data_path}"
     rsync -a $verbosity -R --delay-updates --delete-after $exclude_files $rsync_srcs ${conf_data_path}
 
-
     # Also make a copy of files modified during puppet run
     echo "Gathering files modified after $(stat -c '%y' $origin_of_time)"
 
@@ -121,7 +127,7 @@ if [ -z "$NO_ARCHIVE" ]; then
     echo "Ensuring the removed config files are also purged in ${puppet_generated_path}:"
     cat $TMPFILE | sort
     cat $TMPFILE | xargs -n1 -r -I{} \
-        bash -c "test -f ${puppet_generated_path}/{} && rm -f ${puppet_generated_path}/{}"
+        bash -c "rm -rf ${puppet_generated_path}/{}"
     exec 5>&1
     exec 1>$TMPFILE2
     find $rsync_srcs -newer $origin_of_time -not -path '/etc/puppet*' -print0
@@ -132,6 +138,16 @@ if [ -z "$NO_ARCHIVE" ]; then
     rsync -a $verbosity -R -0 --delay-updates --delete-after $exclude_files \
         --files-from=$TMPFILE2 / ${puppet_generated_path}
 
+    # Cleanup any special files that might have been copied into place
+    # previously because fixes for LP#1860607 did not cleanup and required
+    # manual intervention if a container hit this. We can safely remove these
+    # files because they should be bind mounted into containers
+    for ro in $ro_files; do
+        if [ -e "${puppet_generated_path}/${ro}" ]; then
+            rm -rf "${puppet_generated_path}/${ro}"
+        fi
+    done
+
     # Write a checksum of the config-data dir, this is used as a
     # salt to trigger container restart when the config changes
     # note: while being excluded from the output, password files
@@ -144,9 +160,9 @@ if [ -z "$NO_ARCHIVE" ]; then
             excluded_original_passwords+=" --exclude=/var/lib/config-data/*${p}"
         fi
     done
-    # We need to exclude the swift ring backups as those change over time and
-    # containers do not need to restart if they change
-    EXCLUDE=--exclude='*/etc/swift/backups/*'\ --exclude='*/etc/libvirt/passwd.db'\ ${excluded_original_passwords}
+    # We need to exclude the swift rings and backups as those change over time
+    # and containers do not need to restart if they change
+    EXCLUDE=--exclude='*/etc/swift/backups/*'\ --exclude='*/etc/swift/*.ring.gz'\ --exclude='*/etc/swift/*.builder'\ --exclude='*/etc/libvirt/passwd.db'\ ${excluded_original_passwords}
 
     # We need to repipe the tar command through 'tar xO' to force text
     # output because otherwise the sed command cannot work. The sed is
